=========
lesana-rm
=========

----------------------------------------
remove an entry from a lesana collection
----------------------------------------

:Author: valhalla@trueelena.org
:Manual section: 1

SYNOPSIS
========

lesana rm [-h] [--collection COLLECTION] entries [entries ...]

DESCRIPTION
===========

Lesana rm removes an entry from the collection, removing both the file
and the cached entry.

OPTIONS
=======

-h, --help
   Prints an help message and exits.
--collection COLLECTION, -c COLLECTION
   The collection to work on. Default is ``.``

